"use strict";(self.webpackChunkipycanvas=self.webpackChunkipycanvas||[]).push([[568],{568:(a,e,n)=>{n.r(e),n.d(e,{CanvasManagerModel:()=>l.CanvasManagerModel,CanvasModel:()=>l.CanvasModel,CanvasView:()=>l.CanvasView,LinearGradientModel:()=>l.LinearGradientModel,MODULE_NAME:()=>M.o,MODULE_VERSION:()=>M.Y,MultiCanvasModel:()=>l.MultiCanvasModel,MultiCanvasView:()=>l.MultiCanvasView,Path2DModel:()=>l.Path2DModel,PatternModel:()=>l.PatternModel,RadialGradientModel:()=>l.RadialGradientModel,RoughCanvasModel:()=>l.RoughCanvasModel});var M=n(657),l=n(901)}}]);